unit UpdateSQL;

interface

uses
{$IFDEF FPC}
  LResources,
{$ENDIF}
{$IFDEF MSWINDOWS}
  Windows, Messages,
{$ENDIF}
  SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DBCtrls, ExtCtrls, Db, Grids, DBGrids,  StdCtrls, ToolWin, ComCtrls,
  Buttons, LiteDACVcl, DemoFrame, LiteDacDemoForm,
  DBAccess, LiteAccess,
  {$IFNDEF FPC}MemDS{$ELSE}MemDataSet{$ENDIF};

type
  TUpdateSQLFrame = class(TDemoFrame)
    LiteQuery: TLiteQuery;
    DataSource: TDataSource;
    LiteUpdateSQL: TLiteUpdateSQL;
    Panel5: TPanel;
    Panel2: TPanel;
    btOpen: TSpeedButton;
    btClose: TSpeedButton;
    btPrepare: TSpeedButton;
    btUnPrepare: TSpeedButton;
    btExecute: TSpeedButton;
    meSQL: TMemo;
    Splitter1: TSplitter;
    Panel3: TPanel;
    Panel1: TPanel;
    btRefreshRecord: TSpeedButton;
    DBNavigator1: TDBNavigator;
    DBGrid: TDBGrid;
    DeleteSQL: TLiteSQL;
    InsertSQL: TLiteSQL;
    ModifyQuery: TLiteQuery;
    RefreshQuery: TLiteQuery;
    Panel4: TPanel;
    cbDeleteObject: TCheckBox;
    cbInsertObject: TCheckBox;
    cbModifyObject: TCheckBox;
    cbRefreshObject: TCheckBox;
    procedure btOpenClick(Sender: TObject);
    procedure btCloseClick(Sender: TObject);
    procedure btPrepareClick(Sender: TObject);
    procedure btUnPrepareClick(Sender: TObject);
    procedure btExecuteClick(Sender: TObject);
    procedure meSQLExit(Sender: TObject);
    procedure btRefreshRecordClick(Sender: TObject);
    procedure cbDeleteObjectClick(Sender: TObject);
  private
    { Private declarations }
    procedure ShowState;
    procedure AssignProperties;
  public
    // Demo management
    procedure Initialize; override;
    procedure SetDebug(Value: boolean); override;
  end;

implementation

{$IFNDEF FPC}
{$IFDEF CLR}
{$R *.nfm}
{$ELSE}
{$R *.dfm}
{$ENDIF}
{$ENDIF}

procedure TUpdateSQLFrame.ShowState;
var
  St:string;

  procedure AddSt(S:string);
  begin
    if St <> '' then
      St:= St + ', ';
    St:= St + S;
  end;

begin
  St:= '';

  if LiteQuery.Prepared then begin
    AddSt('Prepared');

    if LiteQuery.IsQuery then
      AddSt('IsQuery');
  end;

  if LiteQuery.Active then
    AddSt('Active')
  else
    AddSt('Inactive');

  if LiteQuery.Executing then
    AddSt('Executing');

  if LiteQuery.Fetching then
    AddSt('Fetching');

  LiteDacForm.StatusBar.Panels[0].Text:= St;
end;

procedure TUpdateSQLFrame.AssignProperties;
begin
  if LiteQuery.SQL.Text <> meSQL.Lines.Text then
    LiteQuery.SQL.Assign(meSQL.Lines);
end;

procedure TUpdateSQLFrame.meSQLExit(Sender: TObject);
begin
  if Trim(LiteQuery.SQL.Text) <> Trim(meSQL.Lines.Text) then
    LiteQuery.SQL.Text:= meSQL.Lines.Text;
  ShowState;
end;

procedure TUpdateSQLFrame.btOpenClick(Sender: TObject);
begin
  try
    AssignProperties;
    LiteQuery.Open;
  finally
    ShowState;
  end;
end;

procedure TUpdateSQLFrame.btCloseClick(Sender: TObject);
begin
  LiteQuery.Close;
  ShowState;
end;

procedure TUpdateSQLFrame.btPrepareClick(Sender: TObject);
begin
  try
    AssignProperties;
    LiteQuery.Prepare;
  finally
    ShowState;
  end;
end;

procedure TUpdateSQLFrame.btUnPrepareClick(Sender: TObject);
begin
  LiteQuery.UnPrepare;
  ShowState;
end;

procedure TUpdateSQLFrame.btExecuteClick(Sender: TObject);
begin
  try
    AssignProperties;  
    LiteQuery.Execute;
  finally
    ShowState;
  end;
end;

procedure TUpdateSQLFrame.btRefreshRecordClick(Sender: TObject);
begin
  LiteQuery.RefreshRecord;
end;

// Demo management
procedure TUpdateSQLFrame.Initialize;
begin
  inherited;
  LiteQuery.Connection := Connection as TLiteConnection;
  meSQL.Lines.Assign(LiteQuery.SQL);
  ShowState;
end;

procedure TUpdateSQLFrame.SetDebug(Value: boolean);
begin
  LiteQuery.Debug:= Value;
end;

procedure TUpdateSQLFrame.cbDeleteObjectClick(Sender: TObject);
  function GetComponent(cbObject: TCheckBox; Component: TComponent): TComponent;
  begin
    if cbObject.Checked then
      Result := Component
    else
      Result := nil;
  end;
begin
  LiteUpdateSQL.DeleteObject := GetComponent(cbDeleteObject, DeleteSQL);
  LiteUpdateSQL.InsertObject := GetComponent(cbInsertObject, InsertSQL);
  LiteUpdateSQL.ModifyObject := GetComponent(cbModifyObject, ModifyQuery);
  LiteUpdateSQL.RefreshObject := GetComponent(cbRefreshObject, RefreshQuery);
end;

{$IFDEF FPC}
initialization
  {$i UpdateSQL.lrs}
{$ENDIF}
end.
